@@ -6,7 +6,7 @@ sub _getstash { \%{"$_[0]::"} }
 use strict;
 use warnings;
 
-our $VERSION = '2.000006';
+our $VERSION = '2.000007';
 $VERSION =~ tr/_//d;
 
 our %INFO;
@@ -54,6 +54,22 @@ sub _load_module {
   return 1;
 }
 
+sub _is_const {
+  my $sub = shift;
+  my $proto = prototype $sub;
+  if (defined &$sub && defined $proto && $proto eq '') {
+    local *_test_const = $sub;
+    local $@;
+    local $SIG{__DIE__};
+    return !eval {
+      use warnings FATAL => 'all';
+      undef &_test_const;
+      1;
+    };
+  }
+  return !!0;
+}
+
 sub import {
   my $target = caller;
   my $me = shift;
@@ -355,8 +371,10 @@ sub _concrete_methods_of {
     map {;
       no strict 'refs';
       my $code = exists &{"${role}::$_"} ? \&{"${role}::$_"} : undef;
-      ( ! $code or exists $not_methods->{$code} ) ? () : ($_ => $code)
-    } grep +(!ref($stash->{$_}) || ref($stash->{$_}) eq 'CODE'), keys %$stash
+      ( ! $code or exists $not_methods->{$code} or (!/\A\(/ && _is_const($code)) ) ? () : ($_ => $code)
+    }
+    grep +(!ref($stash->{$_}) || ref($stash->{$_}) eq 'CODE'),
+    keys %$stash
   };
 }
 
@@ -379,7 +397,7 @@ sub _install_methods {
   # determine already extant methods of target
   my %has_methods;
   @has_methods{grep
-    +(ref($stash->{$_}) || *{$stash->{$_}}{CODE}),
+    +(ref($stash->{$_}) || exists &{"${to}::$_"}),
     keys %$stash
   } = ();
 
@@ -483,7 +501,7 @@ __END__
 
 =head1 NAME
 
-Role::Tiny - Roles. Like a nouvelle cuisine portion size slice of Moose.
+Role::Tiny - Roles: a nouvelle cuisine portion size slice of Moose
 
 =head1 SYNOPSIS
 
